/*
 * Copyright: Scheer PAS GmbH
 */
package com.scheer.pas.simple;

import ch.e2e.bridge.server.BridgeException;
import ch.e2e.bridge.server.Logger;
import ch.e2e.bridge.server.XumlLibraryClass;

import static ch.e2e.bridge.server.Logger.*;

/**
 * This is a simple Java implementation example that can be compiled to an xUML library for the Designer.
 */
@SuppressWarnings("unused")
@XumlLibraryClass(name = "HelloWorld")
public class HelloWorldExample {

    private static final Logger LOGGER = new Logger();

    /**
     * Returns the provided message or a default message.
     *
     * @param message Provide input for the message to be returned. Defaults to "Hi from the Scheer PAS team!".
     * @return Returns the message entered.
     */
    public static String helloWorld(String message) {
        String msg = message == null || message.isEmpty() ? "Hi from the Scheer PAS team!" : message;
        LOGGER.log(LL_DEBUG, "Internal", "com.scheer.pas.simple", "999", "helloWorld() - answer is '" + msg + "'.");
        return msg;
    }

    /**
     * Throws an exception.
     *
     * @param message Provide the description of the error.
     * @param code Provide the code of the error.
     * @param domain Provide the domain of the error.
     */
     public static void throwException(String message, String code, String domain) {
        throw new BridgeException(message, code, domain);
    }

    /**
     * Throws an exception wrapping the causing throwable.
     *
     * @param message Provide the description of the error cause.
     * @param code Provide the code of the error.
     * @param domain Provide the domain of the error.
     */
    public static void throwExceptionWithCause(String message, String code, String domain) {
        throw new BridgeException(new IllegalStateException(message), code, domain);
    }

    private HelloWorldExample() {
    }

}
